@@ -243,7 +243,7 @@ class Auth(object):
         self.init_render()
         
         @app.before_request
-        def set_user(request):
+        def set_user(request, **kwargs):
             self.get_user(request)
 
 
@@ -253,6 +253,13 @@ class Auth(object):
             auth_loader,
         ])
         self.auth_render = Render(loader=loader)
+
+        self.auth_render.env.globals.update(self.render.env.globals)
+        self.auth_render.env.filters.update(self.render.env.filters)
+        self.auth_render.env.tests.update(self.render.env.tests)
+
+        self.auth_render.response_class = self.render.response_class
+        self.auth_render.default_mimetype = self.render.default_mimetype
     
 
     def _get_user(self, login):
